#include <fork.h>
#include <assert.h>
#include <syscall.h>
#include <io.h>


main() 
{
 pr int t = getct();
 if (__PROC_NR__==0)
   if (__STARTED_PROCS__ >=4)
     pprintf("Using 4 of the %d processors\n\n", __STARTED_PROCS__); 
 assert(__STARTED_PROCS__ >=4);
 pprintf("'Hello world' from processor %d\n", $);
 start 
     farm {
         pprintf("'Goodbye world' from processor %d\n", $);
     }
 t = getct() - t;
 if (__PROC_NR__==0)
    pprintf("Parallel execution time:  %d msec\n", t >> 8);
}
